@@ -16,9 +16,9 @@ our $MapLimit = "512MB";  # map limit
 our $MaxFilesize = 4096;  # max file size in kilobytes
 our $MaxImageArea = 16384;  # max image area in kilobytes (width*height)
 our $MaxImageExtent = 16384;  # max image extent in kilobytes (width*height*frames)
-our $ThreadLimit = 2;  # max number of worker threads
 our $MaxWorkFiles = 8192;  # max number of work files
 our $MemoryLimit = "256MB";  # memory limit
+our $ThreadLimit = "2";  # thread limit
 our $MinExpireAge = 7200;  # minimum expire age
 our $RedirectURL = "http://studio.webbyland.com/MagickStudio/scripts/MagickStudio.cgi";
 our $SponsorIcon = "networkredux.png";
